/*
 nRF24 Multi-Network RX
 Version: 0.1
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 25/05/2013
 Last Modified: 8/06/2013
 
 A multi-addressable software implementation to allow for up to 256 nRF24 modules to be used at the same time.
 Each nRF24 module shares the same TX/RX address so whenever one nRF24 transmits all nearby nRF24's will receive it 
 and only accept it if it matches it's address. 
 The downside is that you need to allow for up to 20ms for a transmit or receive to occur.
 
 Variables include: From address (byte 0), To address (byte 1), Fwd address (to be implemented, byte 2), ACK (byte 3), Data (byte 4 to 31)
 
 */
 
// ATtiny25/45/85 Pin map
//                    +-\/-+
//        Reset PB5  1|o   |8  VCC
//  nRF24L01 CE PB3  2|    |7  PB2 nRF24L01 SCK + LED
// nRF24L01 CSN PB4  3|    |6  PB1 nRF24L01 MO
//              GND  4|    |5  PB0 nRF24L01 MI
//                    +----+

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
//#include "setup.c"
//#include "mirf.c"
#include "setup.h"
#include "mirf.h"

uint8_t data_in[32];
uint8_t data_out[32];

int main(void) {
	setup();
	mirf_init();
	_delay_ms(50);
	mirf_config();
	
	while(1) {
		RX_POWERUP;
		mirf_flush_rx_tx(); // Flush TX/RX
		mirf_CE_hi; // Start listening
		
		// Wait for incoming requests
		while (!(mirf_status() & (1<<RX_DR))) { 
			_delay_us(50);
		}
		mirf_CE_lo; // Stop listening
		
		// Read the data received and process the packet
		if (receive_packet_and_process()) {
			
			// Blink LED
			PORTB |= (1<<PB2);
			_delay_ms(50);
			PORTB &= ~(1<<PB2);
			_delay_ms(50);
		}
	}
}
